@@ -1,6 +1,7 @@
 "ordihull" <-
-    function (ord, groups, display = "sites", draw = c("lines", "polygon"),
-              show.groups, ...)
+    function (ord, groups, display = "sites",
+              draw = c("lines", "polygon", "none"),
+              show.groups, label = FALSE, ...)
 {
     draw <- match.arg(draw)
     pts <- scores(ord, display = display, ...)
@@ -11,6 +12,7 @@
     }
     out <- seq(along = groups)
     inds <- names(table(groups))
+    res <- list()
     for (is in inds) {
         gr <- out[groups == is]
         if (length(gr) > 1) {
@@ -19,8 +21,16 @@
             hpts <- c(hpts, hpts[1])
             if (draw == "lines")
                 ordiArgAbsorber(X[hpts, ], FUN = lines, ...)
-            else ordiArgAbsorber(X[hpts,], FUN = polygon, ...)
+            else if (draw == "polygon")
+                ordiArgAbsorber(X[hpts,], FUN = polygon, ...)
+            if (label && draw != "none") {
+                cntr <- colMeans(X)
+                ordiArgAbsorber(cntr[1], cntr[2], labels = is,
+                                FUN = text, ...)
+            }
+            res[[is]] <- X[hpts,]
         }
     }
-    invisible()
+    class(res) <- "ordihull"
+    invisible(res)
 }
